package com.me.asteroids.systems;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.math.Polygon;
import com.badlogic.gdx.math.Vector2;
import com.me.asteroids.Graphics;
import com.me.asteroids.components.ModelComponent;
import com.me.asteroids.components.PositionComponent;
import com.me.common.ecs.Entity;
import com.me.common.ecs.EntitySystem;

public class ModelRenderSystem extends EntitySystem {

    private ShapeRenderer renderer;

    public ModelRenderSystem(Graphics graphics) {
        super(ModelComponent.class, PositionComponent.class);
        this.renderer = graphics.getShapeRenderer();
    }

    @Override
    public void preProcessing() {
        renderer.setColor(Color.WHITE);
        renderer.begin(ShapeRenderer.ShapeType.Line);
    }

    @Override
    public void processEntity(Entity entity, float dt) {
        ModelComponent modelComponent = entity.getComponent(ModelComponent.class);
        PositionComponent positionComponent = entity.getComponent(PositionComponent.class);

        Polygon model = modelComponent.model;
        Vector2 position = positionComponent.position;
        float rotation = positionComponent.rotation;

        model.setPosition(position.x, position.y);
        model.setRotation(rotation - 90);

        renderer.polygon(model.getTransformedVertices());
    }

    @Override
    public void postProcessing() {
        renderer.end();
    }

}
